@@ -20,6 +20,7 @@ default_headers = {
     "User-Agent": "Mozilla/5.0 (Macintosh; Intel Mac OS X 10.15; rv:105.0) Gecko/20100101 Firefox/105.0",
 }
 default_host = "cli2.mobgi.com"
+hosts = ["cli1.mobgi.com", "cli2.mobgi.com"]
 
 
 def get_media_account(
@@ -27,7 +28,8 @@ def get_media_account(
         cookie: str = None,
         page: int = 1,
         page_size: int = 20,
-        total_count: int = 0
+        total_count: int = 0,
+        host: str = default_host,
 ):
     """
     获取 推广-账户管理下的账户列表
@@ -39,7 +41,7 @@ def get_media_account(
     :return:
     """
 
-    url = 'https://cli2.mobgi.com/Media/Account/getList'
+    url = f'https://{host}/Media/Account/getList'
     data = {
         "media_type": media_type,
         "advertiser_type": "1",
@@ -74,6 +76,8 @@ def get_ad_report(
         conditions: dict = None,
         kpis: list = None,
         relate_dims: list = None,
+        host: str = default_host,
+        db_type: str = "doris"
 ):
     """
     报表-广告报表
@@ -97,7 +101,7 @@ def get_ad_report(
         start_date = lazytime.get_date_string(days=0)
     if not end_date:
         end_date = lazytime.get_date_string(days=0)
-    url = "https://cli2.mobgi.com/ReportV23/AdReport/getReport"
+    url = f"https://{host}/ReportV23/AdReport/getReport"
     data = {
         "start_date": start_date,
         "end_date": end_date,
@@ -109,6 +113,7 @@ def get_ad_report(
         "data_dim": data_dim,
         "sort_field": sort_field,
         "sort_direction": sort_direction,
+        "db_type": db_type
     }
     if media_type == "baidu":
         if not conditions:
@@ -131,7 +136,7 @@ def get_ad_report(
         if not relate_dims:
             relate_dims = ["advertiser_id"]
 
-    elif media_type == "gdt_new":
+    elif media_type in ["gdt_new", "gdt_upgrade"]:
         if not conditions:
             conditions = {
                     "keyword": "",
@@ -188,8 +193,8 @@ def get_ad_report(
             relate_dims = ["advertiser_id"]
 
     else:
-        showlog.warning("未知媒体类型")
-        return
+        showlog.warning("未知媒体类型，不指定默认参数")
+        pass
 
     headers = copy.deepcopy(default_headers)
     headers["Cookie"] = cookie
@@ -220,7 +225,9 @@ def get_plan_list(
         cdt_start_date: str = None,
         cdt_end_date: str = None,
         kpis: list = None,
-        req_source: str = None
+        req_source: str = None,
+        host: str = default_host,
+base_infos: list = None
 ):
     """
     获取推广计划
@@ -250,6 +257,23 @@ def get_plan_list(
         cdt_start_date = lazytime.get_date_string(days=-365)
     if not cdt_end_date:
         cdt_end_date = lazytime.get_date_string(days=0)
+    if not base_infos:
+        base_infos = [
+        "adgroup_name",
+        "adgroup_id",
+        "advertiser_id",
+        "company",
+        "optimization_goal",
+        "system_status",
+        "bid_amount",
+        "deep_conversion_worth_roi",
+        "created_time",
+        "user_name",
+        "daily_budget",
+        "bid_mode",
+        "deep_conversion_spec",
+        "begin_date"
+    ]
     data = {
         "start_date": start_date,
         "end_date": end_date,
@@ -257,10 +281,11 @@ def get_plan_list(
         "page_size": page_size,
         "sort_field": sort_field,
         "sort_direction": sort_direction,
-        "data_type": data_type
+        "data_type": data_type,
+        "base_infos": base_infos
     }
     if media_type == "baidu":
-        url = "https://cli2.mobgi.com/Baidu/Campaign/getList"
+        url = f"https://{host}/Baidu/Campaign/getList"
         if not conditions:
             conditions = {
                 "cl_project_id": [],
@@ -276,8 +301,8 @@ def get_plan_list(
             if media_account_id:
                 conditions["media_account_id"] = [media_account_id]
         data["conditions"] = json.dumps(conditions)
-    elif media_type == "gdt_new":
-        url = "https://cli2.mobgi.com/Gdt/MainList/getList"
+    elif media_type in ["gdt_new"]:
+        url = f"https://{host}/Gdt/MainList/getList"
         if not conditions:
             conditions = {
                 "is_deleted": "",
@@ -332,10 +357,12 @@ def update_ad_batch(
         campaign_feed_id: int = None,
         campaign_feed_ids: list = None,
 
-        operate: str = "disable"
+        operate: str = "disable",
+        host: str = default_host
 ):
     """
     暂停广告
+    : param operate: 操作：暂停：DISABLE，删除：DELETE
     :return:
     """
     headers = copy.deepcopy(default_headers)
@@ -349,12 +376,12 @@ def update_ad_batch(
             "field": operate
         }
         if adgroup_id or adgroup_ids:
-            url = "https://cli2.mobgi.com/Gdt/MainList/updateAdGroupBatch"
+            url = f"https://{host}/Gdt/MainList/updateAdGroupBatch"
             if not adgroup_ids:
                 adgroup_ids = [adgroup_id]
             post_data["adgroup_ids"] = adgroup_ids
         elif campaign_id or campaign_ids:
-            url = "https://cli2.mobgi.com/Gdt/MainList/updateCampaignBatch"
+            url = f"https://{host}/Gdt/MainList/updateCampaignBatch"
             if campaign_id and not campaign_ids:
                 campaign_ids = [campaign_id]
             post_data["campaign_ids"] = campaign_ids
@@ -363,7 +390,7 @@ def update_ad_batch(
 
     elif media_type == "baidu":
         if adgroup_feed_id or adgroup_feed_ids:
-            url = "https://cli2.mobgi.com/Baidu/AdGroup/batchUpdate"
+            url = f"https://{host}/Baidu/AdGroup/batchUpdate"
             if adgroup_feed_id and not adgroup_feed_ids:
                 adgroup_feed_ids = [adgroup_feed_id]
             post_data = {
@@ -371,7 +398,7 @@ def update_ad_batch(
                 "opt_status": operate
             }
         elif campaign_feed_id or campaign_feed_ids:
-            url = "https://cli2.mobgi.com/Baidu/Campaign/batchUpdate"
+            url = f"https://{host}/Baidu/Campaign/batchUpdate"
             if campaign_feed_id and not campaign_feed_ids:
                 campaign_feed_ids = [campaign_feed_id]
             post_data = {
@@ -381,7 +408,7 @@ def update_ad_batch(
         else:
             return
     elif media_type == "toutiao_upgrade":
-        url = "https://cli2.mobgi.com/Toutiao/Promotion/updateStatus"
+        url = f"https://{host}/Toutiao/Promotion/updateStatus"
         if promotion_id and not promotion_ids:
             promotion_ids = [promotion_id]
         post_data = {
@@ -446,7 +473,8 @@ def get_material_report(
         data_type: str = "list",
         sort_direction: str = "desc",
         conditions: dict = None,
-        relate_dims: list = None
+        relate_dims: list = None,
+        host: str = "cli2.mobgi.com",
 ):
     """
     报表-素材报表
@@ -455,22 +483,26 @@ def get_material_report(
     :param end_date:
     :param page:
     :param page_size:
-    :param media_type:媒体：gdt_new|广点通(新指标体系)，toutiao_upgrade|今日头条2.0，aggregate|不限,baidu:百度信息流
-    :param data_dim:
+    :param media_type:媒体：gdt_new|广点通(新指标体系)，toutiao_upgrade|今日头条2.0/巨量广告，aggregate|不限,baidu:百度信息流
+    :param data_dim: 数据维度：素材
     :param data_type:
-    :param sort_direction:
-    :param sort_field:
+    :param sort_direction: 排序
+    :param sort_field: 排序字段，stat_cost：消耗
     :param time_dim: 时间维度的数据汇总方式，days：分日，sum：汇总
     :param conditions:
     :param kpis:
-    :param relate_dims:
+    :param relate_dims:关联维度,
+        material_create_time:上传时间 --> material_create_time
+        owner_user_id:优化师 --> user_name
+        creative_user_id:创意人 --> creative_user
+    :param host:
     :return:
     """
     if not start_date:
         start_date = lazytime.get_date_string(days=0)
     if not end_date:
         end_date = lazytime.get_date_string(days=0)
-    url = "https://cli2.mobgi.com/ReportV23/MaterialReport/getReport"
+    url = f"https://{host}/ReportV23/MaterialReport/getReport"
     data = {
         "time_dim": time_dim,
         "media_type": media_type,
@@ -573,7 +605,8 @@ def get_account_report(
         conditions: dict = None,
         kpis: list = None,
         base_infos: list = None,
-        time_line: str = "REPORTING_TIME"
+        time_line: str = "REPORTING_TIME",
+        host: str = "cli2.mobgi.com",
 ):
     """
     推广-广告管理-媒体账户
@@ -594,7 +627,7 @@ def get_account_report(
         start_date = lazytime.get_date_string(days=0)
     if not end_date:
         end_date = lazytime.get_date_string(days=0)
-    url = "https://cli2.mobgi.com/MainPanelReport/AccountReport/getReport"
+    url = f"https://{host}/MainPanelReport/AccountReport/getReport"
     data = {
         "data_type": data_type,
         "media_type": media_type,
@@ -899,3 +932,501 @@ def deactivate_material(
         json=data,
         headers=headers
     )
+
+
+def get_toutiao_promotion(
+        cookie: str,
+        user_id: list = None,
+        material_id: str = None,
+        cdt_start_date: str = None,
+        cdt_end_date: str = None,
+        start_date: str = None,
+        end_date: str = None,
+        host: str = default_host,
+        page: int = 1,
+        page_size: int = 20,
+        sort_field: str = "create_time",
+        sort_direction: str = "desc",
+        data_type: str = "list"
+):
+    """
+    推广-巨量广告-广告 查询
+    :param cookie:
+    :param material_id: 素材ID
+    :param cdt_start_date: 创建时间，例如：2025-07-05 00:00:00
+    :param cdt_end_date: 创建时间，例如：2025-08-04 23:59:59
+    :param start_date: 数据日期，例如：2025-08-04
+    :param end_date: 数据日期，例如：2025-08-04
+    :param host:
+    :return:
+    """
+    url = f"https://{host}/Toutiao/Promotion/getList"
+    if not user_id:
+        user_id = []
+    conditions = {
+        "search_field":"promotion_name",
+        "search_keyword":"",
+        "cl_project_id":[],
+        "cl_app_id":[],
+        "user_id": user_id,
+        "media_account_id":[],
+        "companys":[],
+        "landing_type":"",
+        "delivery_mode":"",
+        "project_id":[],
+        "status_first":"",
+        "scene_type":[],
+        "strategy_id":[],
+        "ad_type":"",
+        "learning_phase":[],
+        "star_delivery_type":"",
+        "star_task_id":"",
+        "app_type":"",
+        "external_action":[],
+        "deep_external_action":[],
+        "deep_bid_type":[],
+        "material_id": material_id,
+        "search_type":"like",
+        "combinatorial_id":"",
+        "status":"",
+        "status_second":"",
+        "cdt_start_date": cdt_start_date,
+        "cdt_end_date": cdt_end_date
+    }
+    data = {
+        "conditions": json.dumps(conditions),
+        "start_date": start_date,
+        "end_date": end_date,
+        "page": page,
+        "page_size": page_size,
+        # "total_count": 1,
+        # "total_page": 1,
+        "sort_field": sort_field,
+        "sort_direction": sort_direction,
+        "data_type": data_type
+    }
+    headers = copy.deepcopy(default_headers)
+    headers["Cookie"] = cookie
+    if host:
+        headers["Host"] = host
+    return lazyrequests.lazy_requests(
+        method="POST",
+        url=url,
+        json=data,
+        headers=headers
+    )
+
+
+def MainPanelReport_AdReport_getReport(
+        cookie: str,
+        media_type: str,
+        sort_field: str,
+        media_account_id: int = None,
+        page: int = 1,
+        page_size: int = 20,
+        start_date: str = None,
+        end_date: str = None,
+        sort_direction: str = "desc",
+        data_type: str = "list",
+        conditions: dict = None,
+        cdt_start_date: str = None,
+        cdt_end_date: str = None,
+        kpis: list = None,
+        req_source: str = None,
+
+        base_infos: list = None,
+        search_field: str = None,
+        search_keyword: str = None,
+        time_line: str = None,
+
+        scheme: str = "https",
+        host: str = default_host,
+        filename: str = "/MainPanelReport/AdReport/getReport"
+):
+    """
+    推广-广告管理-广告
+    :param cookie:
+    :param media_type:
+    :param media_account_id:
+    :param sort_field: 排序字段
+    :param page:
+    :param page_size:
+    :param start_date: 数据开始日期
+    :param end_date: 数据结束日期
+    :param sort_direction: 排序方式，desc:降序
+    :param data_type:
+    :param conditions: 搜索条件
+    :param cdt_start_date: 创建开始时间
+    :param cdt_end_date: 创建结束时间
+    :param kpis:
+    :param req_source: 腾讯需要的参数
+    :return:
+    """
+    url = f"{scheme}://{host}{filename}"
+    if not start_date:
+        start_date = lazytime.get_date_string(days=0)
+    if not end_date:
+        end_date = lazytime.get_date_string(days=0)
+    if not cdt_start_date:
+        cdt_start_date = lazytime.get_date_string(days=-365)
+    if not cdt_end_date:
+        cdt_end_date = lazytime.get_date_string(days=0)
+    if not base_infos:
+        base_infos = [
+            "adgroup_name",
+            "adgroup_id",
+            "advertiser_id",
+            "company",
+            "optimization_goal",
+            "system_status",
+            "bid_amount",
+            "deep_conversion_worth_roi",
+            "created_time",
+            "user_name",
+            "daily_budget",
+            "bid_mode",
+            "deep_conversion_spec",
+            "begin_date"
+        ]
+
+    data = dict()
+
+    # 默认参数
+    if base_infos:
+        data["base_infos"] = base_infos
+    if conditions:
+        data["conditions"] = conditions
+    if data_type:
+        data["data_type"] = data_type
+    if end_date:
+        data["end_date"] = end_date
+    if kpis:
+        data["kpis"] = kpis
+    if media_type:
+        data["media_type"] = media_type
+    if page:
+        data["page"] = page
+    if page_size:
+        data["page_size"] = page_size
+    if sort_direction:
+        data["sort_direction"] = sort_direction
+    if sort_field:
+        data["sort_field"] = sort_field
+    if start_date:
+        data["start_date"] = start_date
+    if time_line:
+        data["time_line"] = time_line
+    if req_source:
+        data["req_source"] = req_source
+
+    if media_type == "baidu":
+        if not conditions:
+            conditions = {
+                "cl_project_id": [],
+                "optimize_user_id": [],
+                "media_account_id": [],
+                "extension_subject": [],
+                "status": "",
+                "keyword": "",
+                "companys": [],
+                "cdt_start_date": f"{cdt_start_date} 00:00:00",
+                "cdt_end_date": f"{cdt_end_date} 23:59:59"
+            }
+            if media_account_id:
+                conditions["media_account_id"] = [media_account_id]
+        data["conditions"] = json.dumps(conditions)
+
+    elif media_type in ["gdt_new", "gdt_upgrade"]:
+        if not time_line:
+            time_line = "REPORTING_TIME"
+        if not conditions:
+            conditions = {
+                "is_deleted": "",
+                "auto_acquisition_status": [],
+                "combinatorial_id": [],
+                "companys": [],
+                "configured_status": ["STATUS_NO_DELETED"],  # 所有未删除
+                "created_time": [cdt_start_date, cdt_end_date],
+                "last_modified_time": [],
+                "media_project_id": [],
+                "owner_user_id": [],
+                "search_field": search_field,
+                "search_keyword": search_keyword,
+                "system_status": [],
+                "time_line": time_line,
+            }
+        data["conditions"] = json.dumps(conditions)
+        if time_line:
+            data["time_line"] = time_line
+    else:
+        pass
+    headers = copy.deepcopy(default_headers)
+    headers["Cookie"] = cookie
+    return lazyrequests.lazy_requests(
+        method="POST",
+        url=url,
+        json=data,
+        headers=headers
+    )
+
+
+def MainPanelReport_AccountReport_getReport(
+        cookie: str,
+        media_type: str,
+        sort_field: str,
+        media_account_id: int = None,
+        page: int = 1,
+        page_size: int = 20,
+        start_date: str = None,
+        end_date: str = None,
+        sort_direction: str = "desc",
+        data_type: str = "list",
+        conditions: dict = None,
+        cdt_start_date: str = None,
+        cdt_end_date: str = None,
+        kpis: list = None,
+        req_source: str = None,
+
+        base_infos: list = None,
+        search_field: str = None,
+        search_keyword: str = None,
+        time_line: str = None,
+
+        scheme: str = "https",
+        host: str = default_host,
+        filename: str = "/MainPanelReport/AccountReport/getReport"
+):
+    """
+    推广-广告管理-账户
+    :param cookie:
+    :param media_type:
+    :param media_account_id:
+    :param sort_field: 排序字段
+    :param page:
+    :param page_size:
+    :param start_date: 数据开始日期
+    :param end_date: 数据结束日期
+    :param sort_direction: 排序方式，desc:降序
+    :param data_type:
+    :param conditions: 搜索条件
+    :param cdt_start_date: 创建开始时间
+    :param cdt_end_date: 创建结束时间
+    :param kpis:
+    :param req_source: 腾讯需要的参数
+    :return:
+    """
+    url = f"{scheme}://{host}{filename}"
+    data = dict()
+
+    # 默认参数
+    if base_infos:
+        data["base_infos"] = base_infos
+    if conditions:
+        data["conditions"] = conditions
+    if data_type:
+        data["data_type"] = data_type
+    if end_date:
+        data["end_date"] = end_date
+    if kpis:
+        data["kpis"] = kpis
+    if media_type:
+        data["media_type"] = media_type
+    if page:
+        data["page"] = page
+    if page_size:
+        data["page_size"] = page_size
+    if sort_direction:
+        data["sort_direction"] = sort_direction
+    if sort_field:
+        data["sort_field"] = sort_field
+    if start_date:
+        data["start_date"] = start_date
+    if time_line:
+        data["time_line"] = time_line
+    if req_source:
+        data["req_source"] = req_source
+
+    headers = copy.deepcopy(default_headers)
+    headers["Cookie"] = cookie
+    return lazyrequests.lazy_requests(
+        method="POST",
+        url=url,
+        json=data,
+        headers=headers
+    )
+
+
+def Advertiser_getRealAdvertiserData(
+        cookie: str,
+        start_date: str = None,
+        end_date: str = None,
+        media_account_ids: list = None,
+        conditions: str = None,
+        scheme: str = "https",
+        host: str = default_host,
+        filename: str = "/Toutiao/Advertiser/getRealAdvertiserData"
+):
+    """
+    推广-广告管理-广告 获取最新的广告数据
+    :param cookie:
+    :param start_date: 数据开始日期
+    :param end_date: 数据结束日期
+    :return:
+    """
+    url = f"{scheme}://{host}{filename}"
+    if not start_date:
+        start_date = lazytime.get_date_string(days=0)
+    if not end_date:
+        end_date = lazytime.get_date_string(days=0)
+
+    if not conditions and media_account_ids:
+        conditions_list = list()
+        for each_media_account_id in media_account_ids:
+            conditions_list.append({"media_account_id": str(each_media_account_id)})
+        conditions = json.dumps(conditions_list)
+    data = {
+        "conditions": conditions,
+        "start_date": start_date,
+        "end_date": end_date
+    }
+    headers = copy.deepcopy(default_headers)
+    headers["Cookie"] = cookie
+    return lazyrequests.lazy_requests(
+        method="POST",
+        url=url,
+        json=data,
+        headers=headers
+    )
+
+
+def Project_getList(
+        cookie: str,
+        sort_field: str,
+        start_date: str = None,
+        end_date: str = None,
+        media_account_ids: list = None,
+        conditions: str = None,
+        data_type: str = "list",
+        page: int = 1,
+        page_size: int = 20,
+        sort_direction: str = "desc",
+        total_count: int = None,
+        total_page: int = None,
+
+        scheme: str = "https",
+        host: str = default_host,
+        filename: str = "/Toutiao/Project/getList"
+):
+    """
+    推广-广告管理-项目
+    :param cookie:
+    :param start_date: 数据开始日期
+    :param end_date: 数据结束日期
+    :return:
+    """
+    url = f"{scheme}://{host}{filename}"
+    if not start_date:
+        start_date = lazytime.get_date_string(days=0)
+    if not end_date:
+        end_date = lazytime.get_date_string(days=0)
+
+    if not conditions and media_account_ids:
+        conditions_list = list()
+        for each_media_account_id in media_account_ids:
+            conditions_list.append({"media_account_id": str(each_media_account_id)})
+        conditions = json.dumps(conditions_list)
+
+    data = dict()
+    if conditions:
+        data["conditions"] = conditions
+    if data_type:
+        data["data_type"] = data_type
+    if start_date:
+        data["start_date"] = start_date
+    if end_date:
+        data["end_date"] = end_date
+    if page:
+        data["page"] = page
+    if page_size:
+        data["page_size"] = page_size
+    if sort_direction:
+        data["sort_direction"] = sort_direction
+    if sort_field:
+        data["sort_field"] = sort_field
+    if total_count:
+        data["total_count"] = total_count
+    if total_page:
+        data["total_page"] = total_page
+
+    headers = copy.deepcopy(default_headers)
+    headers["Cookie"] = cookie
+    return lazyrequests.lazy_requests(
+        method="POST",
+        url=url,
+        json=data,
+        headers=headers
+    )
+
+
+def Project_updateStatus(
+        cookie: str,
+        opt_status: str,
+        project_ids: list = None,
+        time: str = None,
+
+        scheme: str = "https",
+        host: str = default_host,
+        filename: str = "/Toutiao/Project/updateStatus"
+):
+    """
+    推广-广告管理-项目 操作
+    :param cookie:
+    :param start_date: 数据开始日期
+    :param end_date: 数据结束日期
+    :return:
+    """
+    url = f"{scheme}://{host}{filename}"
+
+    data = dict()
+    if opt_status:
+        data["opt_status"] = opt_status
+    if project_ids:
+        data["project_ids"] = project_ids
+    if time:
+        data["time"] = time
+    headers = copy.deepcopy(default_headers)
+    headers["Cookie"] = cookie
+    return lazyrequests.lazy_requests(
+        method="POST",
+        url=url,
+        json=data,
+        headers=headers
+    )
+
+
+def getTaskResult(
+        cookie: str,
+        batch_id: str = None,
+
+        scheme: str = "https",
+        host: str = default_host,
+        filename: str = "/Toutiao/Tools/getTaskResult"
+):
+    """
+    获取任务结果
+    :param cookie:
+    :param batch_id:
+    :return:
+    """
+    url = f"{scheme}://{host}{filename}"
+    data = dict()
+    if batch_id:
+        data["batch_id"] = batch_id
+    headers = copy.deepcopy(default_headers)
+    headers["Cookie"] = cookie
+    return lazyrequests.lazy_requests(
+        method="POST",
+        url=url,
+        json=data,
+        headers=headers
+    )
\ No newline at end of file
